@@ -80,7 +80,10 @@ hook_plot_tex = function(x, options) {
   fig.ncol = options$fig.ncol %n% fig.num
   if (is.null(fig.sep <- options$fig.sep)) {
     fig.sep = character(fig.num)
-    if (fig.ncol < fig.num) fig.sep[seq(fig.ncol, fig.num - 1L, fig.ncol)] = '\\newline'
+    # add \newline after every fig.ncol figures; if the last figure is not the
+    # last on its row, skip adding \newline (not necessary, but may be harmless)
+    if (fig.ncol < fig.num)
+      fig.sep[seq(fig.ncol, fig.num - (fig.num %% fig.ncol > 0), fig.ncol)] = '\\newline'
   }
   sep.cur = NULL
 
@@ -143,7 +146,7 @@ hook_plot_tex = function(x, options) {
       }
       scap = if (is.null(scap) || is.na(scap)) '' else sprintf('[%s]', scap)
       cap = if (cap == '') '' else sprintf(
-        '\\caption%s{%s}%s\n', scap, cap,
+        '\\caption%s{%s}%s\n', escape_percent(scap), escape_percent(cap),
         create_label(lab, if (mcap) c('-', fig.cur), latex = TRUE)
       )
       fig2 = sprintf('%s\\end{%s}\n', cap, options$fig.env)
@@ -189,6 +192,9 @@ hook_plot_tex = function(x, options) {
   )
 }
 
+# % -> \%, but do not touch \%
+escape_percent = function(x) gsub('(?<!\\\\)%', '\\\\%', x, perl = TRUE)
+
 .chunk.hook.tex = function(x, options) {
   ai = output_asis(x, options)
   col = if (!ai) paste0(
